@@ -385,11 +385,14 @@
  * Internal
  * -----
  * ensure all source line lengths are less than 80
- *    after someone or something wrapped the 2.14 archive,
- *    and it would not compile (split a character string literal)
+ *    after someone or something wrapped the 2.14 archive, and it
+ *    would not compile (split a character string literal).
+ *    Thanks to Robert Hagopian (rhagopia@terminator.rs.itd.umich.edu)
+ *    and to L L Campbell (campbell@brahms.udel.edu) for bringing this
+ *    problem to my attention.
  *    [recall that shar usually prepends X, which bumps the line length by 1]
- *    [also, this makes editing with emacs at 80 columns a bit better]
- * add check_linelen to Makefile to ensure compliance
+ *    [also, < 80 makes editing with emacs at 80 columns a bit better]
+ * add check_linelen to Makefile to help ensure compliance
  * -----
  * Joseph Skudlarek  Mentor Graphics  8005 SW Boeckman Rd  Wilsonville OR 97070
  * (503) 685-1576 (work)
@@ -397,6 +400,28 @@
  * Version 2.15 15Nov93
  * ----------------------------------------------------------------------------
 
+ * ----------------------------------------------------------------------------
+ * External
+ * -----
+ * -----
+ * Internal
+ * -----
+ * fix original bug of failing to convert lengths when extracting data
+ *    and resource forks from MacBinary files -- thanks to Thomas Lange
+ *    <tlange@namu01.gwdg.de> for finding and supplying the fix for this bug
+ * tidy up for Alpha OSF1 -- thanks to Holger Debelts
+ *    <Debelts@rrz.Uni-Koeln.DE> for providing a fix for time()'s redeclaration
+ * check <= 80 on *archive*, and avoid always rebuilding shar
+ *    due to unfulfilled check_linelen dependency
+ * improve 2.15 comments
+ * toss uninteresting lint messages
+ * -----
+ * Joseph Skudlarek  Mentor Graphics  8005 SW Boeckman Rd  Wilsonville OR 97070
+ * (503) 685-1576 (work)
+ * {Jskud@wv.MentorG.com,Joseph_Skudlarek@MentorG.com}
+ * Version 2.16 14Oct94
+ * ----------------------------------------------------------------------------
+
  * ----------------------------------------------------------------------------
  * This program may be freely distributed for non-profit purposes.  It
  * may not be sold, by itself or as part of a collection of software.
@@ -975,7 +1000,7 @@ un_other(mode)
 	register ulong b;				/* not character, must hold EOF diagnostic */
 	register ulong nchars;
 	int extra_chars;
-	short crc, calc_mb_crc();
+	short crc;
 	long len;
 
 	while (hqxnames_left[0][0] != '-') {
@@ -1187,7 +1212,7 @@ re_other(mode)
 
 		/* process the data fork */
 		bcopy((char*)info.dlen, (char *) &temp, 4);
-		nchars = temp;
+		nchars = mac2long(temp);
 		extra_chars = 127 - (nchars + 127) % 128;
 
 		if (*data_fname) {
@@ -1230,7 +1255,7 @@ re_other(mode)
 		/* process the rsrc fork */
 
 		bcopy((char*)info.rlen, (char *) &temp, 4);
-		nchars = temp;
+		nchars = mac2long(temp);
 
 		if (*rsrc_fname) {
 			while (nchars--) {
